summaryrefslogtreecommitdiffstats
path: root/store/storetest/mocks/PostStore.go
diff options
context:
space:
mode:
Diffstat (limited to 'store/storetest/mocks/PostStore.go')
-rw-r--r--store/storetest/mocks/PostStore.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/store/storetest/mocks/PostStore.go b/store/storetest/mocks/PostStore.go
index 8f56bc4b2..f97b8a2f6 100644
--- a/store/storetest/mocks/PostStore.go
+++ b/store/storetest/mocks/PostStore.go
@@ -1,4 +1,4 @@
-// Code generated by mockery v1.0.0. DO NOT EDIT.
+// Code generated by mockery v1.0.0
// Regenerate this file using `make store-mocks`.
@@ -66,9 +66,9 @@ func (_m *PostStore) ClearCaches() {
_m.Called()
}
// Delete provides a mock function with given fields: postId, time
func (_m *PostStore) Delete(postId string, time int64, deleteByID string) store.StoreChannel {
- ret := _m.Called(postId, time)
+ ret := _m.Called(postId, time, deleteByID)
var r0 store.StoreChannel
if rf, ok := ret.Get(0).(func(string, int64, string) store.StoreChannel); ok {
@@ -66,9 +66,9 @@ func (_m *PostStore) ClearCaches() {
_m.Called()
}
-// Delete provides a mock function with given fields: postId, time
+// Delete provides a mock function with given fields: postId, time, deleteByID
func (_m *PostStore) Delete(postId string, time int64, deleteByID string) store.StoreChannel {